@@ -1,3 +1,16 @@
+#![forbid(unsafe_code, future_incompatible)]
+#![deny(
+    missing_docs,
+    missing_debug_implementations,
+    missing_copy_implementations,
+    nonstandard_style,
+    unused_qualifications,
+    unused_import_braces,
+    unused_extern_crates,
+    trivial_casts,
+    trivial_numeric_casts
+)]
+#![cfg_attr(docsrs, feature(doc_cfg))]
 //! The surf middleware implementation for http-cache.
 //! ```no_run
 //! use http_cache_surf::{Cache, CacheMode, CACacheManager, HttpCache};
@@ -31,12 +44,15 @@ use url::Url;
 pub use http_cache::{CacheMode, CacheOptions, HttpCache, HttpResponse};
 
 #[cfg(feature = "manager-cacache")]
+#[cfg_attr(docsrs, doc(cfg(feature = "manager-cacache")))]
 pub use http_cache::CACacheManager;
 
 #[cfg(feature = "manager-moka")]
-pub use http_cache::MokaManager;
+#[cfg_attr(docsrs, doc(cfg(feature = "manager-moka")))]
+pub use http_cache::{MokaCache, MokaCacheBuilder, MokaManager};
 
 /// Wrapper for [`HttpCache`]
+#[derive(Debug)]
 pub struct Cache<T: CacheManager + Send + Sync + 'static>(pub HttpCache<T>);
 
 /// Implements ['Middleware'] for surf
@@ -138,9 +154,9 @@ impl<T: CacheManager + 'static + Send + Sync> surf::middleware::Middleware
 {
     async fn handle(
         &self,
-        req: surf::Request,
-        client: surf::Client,
-        next: surf::middleware::Next<'_>,
+        req: Request,
+        client: Client,
+        next: Next<'_>,
     ) -> std::result::Result<surf::Response, http_types::Error> {
         let middleware = SurfMiddleware { req, client, next };
         let res = self.0.run(middleware).await?;
